@@ -13,6 +13,6 @@ The different modules are document here:
 
 """
 
-from .points import Point3D, Point2D
+from .points import Point3D, Point2D, VanishingPoint
 from .calib import Calib, parameters_to_affine_transform, compute_rotation_matrix, line_plane_intersection
 from .draw import ProjectiveDrawer
